@@ -44,7 +44,7 @@
 
 #include <tdelocale.h>
 #include <kprogress.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeconfig.h>
 #include <tdeapplication.h>
 #include <kdebug.h>
